<?php
/*
Plugin Name: gp hide menu options by role
Plugin URI: https://github.com/gammapartners
Description: hides menu options based on user role
Version: 1.0.0
Author: Rene Manqueros
Author URI: https://github.com/reneManqueros/
License:     GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
*/
function gp_hide_menu_options_by_role() {
    global $current_user;

    $all_roles = wp_roles()->roles;

    foreach($all_roles as $this_role){
        $this_role_name = $this_role['name'];
        if($this_role_name  != 'Administrator') {
            if(array_key_exists(strtolower($this_role_name), $current_user->caps) == 1) {
                global $menu;
                $gp_options = get_option('gp_hmobr_options');
                $menuhide = explode(';#', $gp_options['gp_role_restrictions-' . $this_role_name ]);

                foreach($menuhide as $mh){
                    remove_menu_page($mh);
                }
            }
        }
    }
}

add_action( 'admin_menu', 'gp_hide_menu_options_by_role', 100);

class gp_hmobr_admin
{
    private $options;
    public function __construct()
    {
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
        add_action( 'admin_init', array( $this, 'page_init' ) );
    }
    public function add_plugin_page()
    {
        add_options_page(
            'Settings Admin',
            'GP Hide Menu Options by Role',
            'manage_options',
            'gp-hide-menu-options-by-role-admin',
            array( $this, 'create_admin_page' )
        );
    }
    public function create_admin_page()
    {
        $this->options = get_option( 'gp_hmobr_options' );
        ?>
        <div class="wrap">
            <h2>Hide Menu Options by Role</h2>
            <form method="post" action="options.php">
                <?php

                settings_fields( 'gp_hmobr_option_group' );
                do_settings_sections( 'my-setting-admin' );

                $all_roles = wp_roles()->roles;

                echo 'Role: <select id="gp_role_picker">';
                foreach($all_roles as $this_role){
                    $this_role_name = $this_role['name'];
                    if($this_role_name  != 'Administrator') {
                       echo '<option>' . $this_role_name . '</option>';
                    }
                }

                echo '</select><br />';

                global $menu;

                $i = 0;
                foreach($menu as $mh){
                    $name = $mh[0];
                    $slug = $mh[2];
                    if($name != ''){
                        echo '<input class="gp_hmobr" id="restriction-' . $i . '" type="checkbox" group="gp_hmobr" value="' . $slug . '" /><label for="restriction-'.$i.'"  class="gp_hmobr">' . $name .'</label><br>';
                    }
                    $i++;
                }

                submit_button();

                $gp_options = get_option('gp_hmobr_options');

                foreach($all_roles as $this_role){
                    $this_role_name = $this_role['name'];
                    if($this_role_name  != 'Administrator') {
                        echo '<input type="text" style="display:none;" id="gp_role_restrictions-' . $this_role_name . '" name="gp_hmobr_options[gp_role_restrictions-' . $this_role_name . ']" value="' . $gp_options['gp_role_restrictions-' . $this_role_name ] . '" /><br>';
                    }
                }

                ?>
            </form>
        </div>
        <script>
            (function($){
                $('.gp_hmobr').on('click', function () {
                    var selected_pages = [];
                    $('input.gp_hmobr:checked').each(function () {
                       selected_pages.push($(this).val());
                    });

                    var selected_role = $('#gp_role_picker option:selected').text();

                    $('#gp_role_restrictions-' + selected_role ).val(selected_pages.join(';#'));
                });

                $('#gp_role_picker').on('change', function () {
                    var selected_role = $('#gp_role_picker option:selected').text();
                    var selected_pages = $('#gp_role_restrictions-' + selected_role ).val().split(';#');
                    $('input.gp_hmobr').removeAttr('checked');
                    selected_pages.forEach(function (this_page) {
                        $('input.gp_hmobr[value="'+this_page+'"]').attr('checked', 'checked');
                    });
                });

                $('#gp_role_picker').trigger('change');

            }(jQuery))
        </script>

        <?php
    }
    public function page_init()
    {
        register_setting(
            'gp_hmobr_option_group',
            'gp_hmobr_options'
        );
        add_settings_section(
            'setting_section_id', 'Hide Menu Options by Role Settings', array(  ), 'my-setting-admin'
        );

        add_settings_field('gp_role_restrictions', '', array( $this, 'gp_admin_field_callback' ), 'my-setting-admin', 'setting_section_id', 'gp_role_restrictions' );

    }
    public function gp_admin_field_callback($field_id)
    {

    }
}
if( is_admin() )
    $settings_page = new gp_hmobr_admin();